/*  Copyright (C) 2008 National Institute For Space Research (INPE) - Brazil.

    This file is part of the TerraLib - a Framework for building GIS enabled applications.

    TerraLib is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License,
    or (at your option) any later version.

    TerraLib is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with TerraLib. See COPYING. If not, write to
    TerraLib Team at <terralib-team@terralib.org>.
 */

/*!
  \file terralib/qt/widgets/se/LinePerpendicularOffsetPropertyItem.h

  \brief A widget used to define the Perpendicular Offset between a line and marks.
*/

#ifndef __TERRALIB_QT_WIDGETS_SE_INTERNAL_LINEPERPENDICULAR_OFFSET_PROPERTYITEM_H 
#define __TERRALIB_QT_WIDGETS_SE_INTERNAL_LINEPERPENDICULAR_OFFSET_PROPERTYITEM_H

// TerraLib
#include "../Config.h"
#include "../propertybrowser/AbstractPropertyItem.h"

namespace te
{
  namespace qt
  {
    namespace widgets
    {
      /*!
        \class LinePerpendicularOffsetPropertyItem

        \brief A widget used to define the Perpendicular Offset between a line and marks.

      */

      class TEQTWIDGETSEXPORT LinePerpendicularOffsetPropertyItem : public te::qt::widgets::AbstractPropertyItem
      {
        Q_OBJECT

        public:
          /** @name Initializer Methods
            *  Methods related to instantiation and destruction.
            */
          //@{

          /*! \brief Constructor */
          LinePerpendicularOffsetPropertyItem(QtTreePropertyBrowser* pb, QColor c = QColor());

          /*! \brief Destructor. */
          ~LinePerpendicularOffsetPropertyItem();

          //@}

          /*!
            \brief Updates the widget form based on internal perpendicular offset element.
            
            \param offset The offset between a line and marks.
          */
          void setLinePerpendicularOffset(double offset);

          /*!
            \brief Get internal perpendicular offset element value.
            
            \return The offset between a line and marks.
          */
          double getLinePerpendicularOffset() const;
          
          /*! \brief Updates the widget form based on internal perpendicular offset element. */
          void updateUi();

        public slots:

          virtual void valueChanged(QtProperty* p, double value);

        signals:

          /*! This signal is emitted when the internal perpendicular offset element is changed. */
          void linePerpendicularOffsetChanged();

        protected:

          QtProperty* m_perpendicularOffset;

          double m_offset;
          
          bool m_update;
      };
    }
  }
}

#endif //__TERRALIB_QT_WIDGETS_SE_INTERNAL_LINEPERPENDICULAR_OFFSET_PROPERTYITEM_H