/*  Copyright (C) 2008 National Institute For Space Research (INPE) - Brazil.

    This file is part of the TerraLib - a Framework for building GIS enabled applications.

    TerraLib is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License,
    or (at your option) any later version.

    TerraLib is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with TerraLib. See COPYING. If not, write to
    TerraLib Team at <terralib-team@terralib.org>.
 */

 /*!
   \file terralib/layout/core/Platform.h

   \brief Configuration flags for the TerrraPrint Layout module.
  */

#ifndef __TERRAPRINT_LAYOUT_INTERNAL_PLATFORM_H
#define __TERRAPRINT_LAYOUT_INTERNAL_PLATFORM_H

#include "Config.h"

#include <string>

namespace te
{
  namespace layout
  {
    /*!
          \brief Returns the path relative to a directory or file in the context of TerraPrint.

          \param path A path to be searched in the TerraPrint context.

          \return A complete path to the file or directory if it is found, otherwise returns an empty string.
        */
    TELAYOUTEXPORT std::string FindInTerraPrintPath(const std::string& path);
  }
}

  /** @name Internationalization Defines
   *  Flags for TerraLib code internationalization.
   */
   //@{

   /*!
     \def TE_LAYOUT_TEXT_DOMAIN

     \brief It contains the name of the text domain used in the translation of messages in Terrralib Layout module.
    */
#define TE_LAYOUT_TEXT_DOMAIN "telayout"

    /*!
      \def TE_LAYOUT_TEXT_DOMAIN_DIR

      \brief It contains the translation catalog directory.
     */
#define TE_LAYOUT_TEXT_DOMAIN_DIR te::layout::FindInTerraPrintPath("terralib/translations/messages")

     /*!
     \def TE_LAYOUT_MAGNET_MODEL_DIR

     \brief It contains the magnet models directory.
     */
#define TE_LAYOUT_MAGNET_MODEL_DIR te::layout::FindInTerraPrintPath("terralib/magnetic_model")

     //@}

#endif //__TERRAPRINT_LAYOUT_INTERNAL_PLATFORM_H
