/*  Copyright (C) 2008 National Institute For Space Research (INPE) - Brazil.

    This file is part of the TerraLib - a Framework for building GIS enabled applications.

    TerraLib is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License,
    or (at your option) any later version.

    TerraLib is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with TerraLib. See COPYING. If not, write to
    TerraLib Team at <terralib-team@terralib.org>.
 */

/*!
  \file ChangePropertyCommand.h
   
  \brief Undo/Redo for changes in component properties.

  \ingroup layout
*/

#ifndef __TERRALIB_LAYOUT_INTERNAL_CHANGE_PROPERTY_COMMAND_ITEM_H 
#define __TERRALIB_LAYOUT_INTERNAL_CHANGE_PROPERTY_COMMAND_ITEM_H

// TerraLib
#include "../../../../core/Config.h"
#include "../../../../core/property/Properties.h"

// Qt
#include <QUndoCommand>

class QGraphicsItem;

namespace te
{
  namespace layout
  {
    class PropertiesOutside;
    class Scene;

    /*!
      \brief Undo/Redo for changes in component properties.
    
      \ingroup layout
    */
    class TELAYOUTEXPORT ChangePropertyCommand : public QUndoCommand
    {
      public:

        /*!
          \brief Constructor

          \param scene
          \param oldProperties
          \param newProperties
          \param outside
          \param parent
        */
        ChangePropertyCommand(te::layout::Scene* scene, const Properties& oldProperties, const Properties& newProperties, bool executeCommandOnCreation = false, PropertiesOutside* outside = 0, QUndoCommand *parent = 0 );

        /*!
          \brief Destructor. Delete all properties.
        */
        virtual ~ChangePropertyCommand() = default;

       /*!
         \brief Executes the selected action (undo or redo) and handles everything that is needed, such as seting the given properties to the item
       */
        virtual void setPropertiesToItems(const Properties& properties);

        /*!
          \brief Reimplemented from QUndoCommand
        */
        virtual void undo();

        /*!
          \brief Reimplemented from QUndoCommand
        */
        virtual void redo();

      protected:

        bool                            m_executeCommandOnCreation;
        te::layout::Scene*              m_scene;
        te::layout::PropertiesOutside*  m_outside;
        te::layout::Properties          m_oldProperties;
        te::layout::Properties          m_newProperties;
    };
  }
}

#endif
